@@ -23,6 +23,9 @@ class RekuestLinkComposition(TypedComposedLink):
     retry: RetryLink = Field(default_factory=RetryLink)
     split: SplitLink
 
+    def _repr_html_inline_(self):
+        return f"<table><tr><td>auth</td><td>{self.auth.maximum_refresh_attempts}</td></tr></table>"
+
 
 class RekuestRath(rath.Rath):
     link: RekuestLinkComposition = Field(default_factory=RekuestLinkComposition)
@@ -32,6 +35,9 @@ class RekuestRath(rath.Rath):
         current_rekuest_rath.set(self)
         return self
 
+    def _repr_html_inline_(self):
+        return f"<table><tr><td>link</td><td>{self.link._repr_html_inline_()}</td></tr></table>"
+
     async def __aexit__(self, exc_type, exc_val, exc_tb):
         await super().__aexit__(exc_type, exc_val, exc_tb)
         current_rekuest_rath.set(None)
